@@ -14,8 +14,15 @@
 
 error_reporting(E_ALL | E_STRICT);
 
+// Make sure version id constant is available.
+if (defined('PHP_VERSION_ID') === false) {
+    $version = explode('.', PHP_VERSION);
+    define('PHP_VERSION_ID', (int) (($version[0] * 10000) + ($version[1] * 100) + $version[2]));
+    unset($version);
+}
+
 // Make sure that we autoload all dependencies if running via Composer.
-if (version_compare(PHP_VERSION, '5.3.2', '>=') === true) {
+if (PHP_VERSION_ID >= 50302) {
     if (file_exists($a = dirname(__FILE__).'/../../../autoload.php') === true) {
         include_once $a;
     } else if (file_exists($a = dirname(__FILE__).'/../vendor/autoload.php') === true) {
@@ -39,7 +46,7 @@ if (file_exists($a = dirname(__FILE__).'/../CodeSniffer.php') === true) {
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_CLI
@@ -245,7 +252,7 @@ class PHP_CodeSniffer_CLI
     public function checkRequirements()
     {
         // Check the PHP version.
-        if (version_compare(PHP_VERSION, '5.1.2', '<') === true) {
+        if (PHP_VERSION_ID < 50102) {
             echo 'ERROR: PHP_CodeSniffer requires PHP version 5.1.2 or greater.'.PHP_EOL;
             exit(2);
         }
@@ -280,6 +287,7 @@ class PHP_CodeSniffer_CLI
         $defaults['showSources']     = false;
         $defaults['extensions']      = array();
         $defaults['sniffs']          = array();
+        $defaults['exclude']         = array();
         $defaults['ignored']         = array();
         $defaults['reportFile']      = null;
         $defaults['generator']       = '';
@@ -348,6 +356,13 @@ class PHP_CodeSniffer_CLI
             $defaults['showProgress'] = (bool) $showProgress;
         }
 
+        $quiet = PHP_CodeSniffer::getConfigData('quiet');
+        if ($quiet === null) {
+            $defaults['quiet'] = false;
+        } else {
+            $defaults['quiet'] = (bool) $quiet;
+        }
+
         $colors = PHP_CodeSniffer::getConfigData('colors');
         if ($colors === null) {
             $defaults['colors'] = false;
@@ -391,7 +406,7 @@ class PHP_CodeSniffer_CLI
         $handle = fopen('php://stdin', 'r');
         if (stream_set_blocking($handle, false) === true) {
             $fileContents = '';
-            while (($line = fgets(STDIN)) !== false) {
+            while (($line = fgets($handle)) !== false) {
                 $fileContents .= $line;
                 usleep(10);
             }
@@ -418,7 +433,10 @@ class PHP_CodeSniffer_CLI
     public function setCommandLineValues($args)
     {
         if (defined('PHP_CODESNIFFER_IN_TESTS') === true) {
-            $this->values = array('stdin' => null);
+            $this->values = array(
+                             'stdin' => null,
+                             'quiet' => true,
+                            );
         } else if (empty($this->values) === true) {
             $this->values = $this->getDefaults();
         }
@@ -473,12 +491,15 @@ class PHP_CodeSniffer_CLI
         case '?':
             $this->printUsage();
             exit(0);
-            break;
         case 'i' :
             $this->printInstalledStandards();
             exit(0);
-            break;
         case 'v' :
+            if ($this->values['quiet'] === true) {
+                // Ignore when quiet mode is enabled.
+                break;
+            }
+
             if (isset($this->values['verbosity']) === false) {
                 $this->values['verbosity'] = 1;
             } else {
@@ -498,8 +519,19 @@ class PHP_CodeSniffer_CLI
             $this->values['explain'] = true;
             break;
         case 'p' :
+            if ($this->values['quiet'] === true) {
+                // Ignore when quiet mode is enabled.
+                break;
+            }
+
             $this->values['showProgress'] = true;
             break;
+        case 'q' :
+            // Quiet mode disables a few other settings as well.
+            $this->values['quiet']        = true;
+            $this->values['showProgress'] = false;
+            $this->values['verbosity']    = 0;
+            break;
         case 'd' :
             $ini = explode('=', $this->_cliArgs[($pos + 1)]);
             $this->_cliArgs[($pos + 1)] = '';
@@ -629,6 +661,17 @@ class PHP_CodeSniffer_CLI
                 }
 
                 $this->values['sniffs'] = $sniffs;
+            } else if (substr($arg, 0, 8) === 'exclude=') {
+                $sniffs = explode(',', substr($arg, 8));
+                foreach ($sniffs as $sniff) {
+                    if (substr_count($sniff, '.') !== 2) {
+                        echo 'ERROR: The specified sniff code "'.$sniff.'" is invalid'.PHP_EOL.PHP_EOL;
+                        $this->printUsage();
+                        exit(2);
+                    }
+                }
+
+                $this->values['exclude'] = $sniffs;
             } else if (substr($arg, 0, 10) === 'bootstrap=') {
                 $files = explode(',', substr($arg, 10));
                 foreach ($files as $file) {
@@ -641,6 +684,33 @@ class PHP_CodeSniffer_CLI
 
                     $this->values['bootstrap'][] = $path;
                 }
+            } else if (substr($arg, 0, 10) === 'file-list=') {
+                $fileList = substr($arg, 10);
+                $path     = PHP_CodeSniffer::realpath($fileList);
+                if ($path === false) {
+                    echo 'ERROR: The specified file list "'.$file.'" does not exist'.PHP_EOL.PHP_EOL;
+                    $this->printUsage();
+                    exit(2);
+                }
+
+                $files = file($path);
+                foreach ($files as $inputFile) {
+                    $inputFile = trim($inputFile);
+
+                    // Skip empty lines.
+                    if ($inputFile === '') {
+                        continue;
+                    }
+
+                    $realFile = PHP_CodeSniffer::realpath($inputFile);
+                    if ($realFile === false) {
+                        echo 'ERROR: The specified file "'.$inputFile.'" does not exist'.PHP_EOL.PHP_EOL;
+                        $this->printUsage();
+                        exit(2);
+                    }
+
+                    $this->values['files'][] = $realFile;
+                }
             } else if (substr($arg, 0, 11) === 'stdin-path=') {
                 $this->values['stdinPath'] = PHP_CodeSniffer::realpath(substr($arg, 11));
 
@@ -722,6 +792,10 @@ class PHP_CodeSniffer_CLI
                     $this->values['standard'] = explode(',', $standards);
                 }
             } else if (substr($arg, 0, 11) === 'extensions=') {
+                if (isset($this->values['extensions']) === false) {
+                    $this->values['extensions'] = array();
+                }
+
                 $this->values['extensions'] = array_merge($this->values['extensions'], explode(',', substr($arg, 11)));
             } else if (substr($arg, 0, 9) === 'severity=') {
                 $this->values['errorSeverity']   = (int) substr($arg, 9);
@@ -867,7 +941,7 @@ class PHP_CodeSniffer_CLI
 
         $phpcs = new PHP_CodeSniffer($values['verbosity'], null, null, null);
         $phpcs->setCli($this);
-        $phpcs->initStandard($values['standard'], $values['sniffs']);
+        $phpcs->initStandard($values['standard'], $values['sniffs'], $values['exclude']);
         $values = $this->values;
 
         $phpcs->setTabWidth($values['tabWidth']);
@@ -1213,13 +1287,14 @@ class PHP_CodeSniffer_CLI
      */
     public function printPHPCSUsage()
     {
-        echo 'Usage: phpcs [-nwlsaepvi] [-d key[=value]] [--colors] [--no-colors] [--stdin-path=<stdinPath>]'.PHP_EOL;
+        echo 'Usage: phpcs [-nwlsaepqvi] [-d key[=value]] [--colors] [--no-colors] [--stdin-path=<stdinPath>]'.PHP_EOL;
         echo '    [--report=<report>] [--report-file=<reportFile>] [--report-<report>=<reportFile>] ...'.PHP_EOL;
         echo '    [--report-width=<reportWidth>] [--generator=<generator>] [--tab-width=<tabWidth>]'.PHP_EOL;
         echo '    [--severity=<severity>] [--error-severity=<severity>] [--warning-severity=<severity>]'.PHP_EOL;
         echo '    [--runtime-set key value] [--config-set key value] [--config-delete key] [--config-show]'.PHP_EOL;
-        echo '    [--standard=<standard>] [--sniffs=<sniffs>] [--encoding=<encoding>]'.PHP_EOL;
-        echo '    [--extensions=<extensions>] [--ignore=<patterns>] [--bootstrap=<bootstrap>] <file> ...'.PHP_EOL;
+        echo '    [--standard=<standard>] [--sniffs=<sniffs>] [--exclude=<sniffs>] [--encoding=<encoding>]'.PHP_EOL;
+        echo '    [--extensions=<extensions>] [--ignore=<patterns>] [--bootstrap=<bootstrap>]'.PHP_EOL;
+        echo '    [--file-list=<fileList>] <file> ...'.PHP_EOL;
         echo '                      Set runtime value (see --config-set) '.PHP_EOL;
         echo '        -n            Do not print warnings (shortcut for --warning-severity=0)'.PHP_EOL;
         echo '        -w            Print both warnings and errors (this is the default)'.PHP_EOL;
@@ -1228,6 +1303,7 @@ class PHP_CodeSniffer_CLI
         echo '        -a            Run interactively'.PHP_EOL;
         echo '        -e            Explain a standard by showing the sniffs it includes'.PHP_EOL;
         echo '        -p            Show progress of the run'.PHP_EOL;
+        echo '        -q            Quiet mode; disables progress and verbose output'.PHP_EOL;
         echo '        -v[v][v]      Print verbose output'.PHP_EOL;
         echo '        -i            Show a list of installed coding standards'.PHP_EOL;
         echo '        -d            Set the [key] php.ini value to [value] or [true] if value is omitted'.PHP_EOL;
@@ -1236,6 +1312,7 @@ class PHP_CodeSniffer_CLI
         echo '        --colors      Use colors in output'.PHP_EOL;
         echo '        --no-colors   Do not use colors in output (this is the default)'.PHP_EOL;
         echo '        <file>        One or more files and/or directories to check'.PHP_EOL;
+        echo '        <fileList>    A file containing a list of files and/or directories to check (one per line)'.PHP_EOL;
         echo '        <stdinPath>   If processing STDIN, the file path that STDIN will be processed as '.PHP_EOL;
         echo '        <bootstrap>   A comma separated list of files to run before processing starts'.PHP_EOL;
         echo '        <encoding>    The encoding of the files being checked (default is iso-8859-1)'.PHP_EOL;
@@ -1253,7 +1330,7 @@ class PHP_CodeSniffer_CLI
         echo '        <reportFile>  Write the report to the specified file path'.PHP_EOL;
         echo '        <reportWidth> How many columns wide screen reports should be printed'.PHP_EOL;
         echo '                      or set to "auto" to use current screen width, where supported'.PHP_EOL;
-        echo '        <sniffs>      A comma separated list of sniff codes to limit the check to'.PHP_EOL;
+        echo '        <sniffs>      A comma separated list of sniff codes to include or exclude during checking'.PHP_EOL;
         echo '                      (all sniffs must be part of the specified standard)'.PHP_EOL;
         echo '        <severity>    The minimum severity required to display an error or warning'.PHP_EOL;
         echo '        <standard>    The name or path of the coding standard to use'.PHP_EOL;
@@ -1270,10 +1347,11 @@ class PHP_CodeSniffer_CLI
     public function printPHPCBFUsage()
     {
         echo 'Usage: phpcbf [-nwli] [-d key[=value]] [--stdin-path=<stdinPath>]'.PHP_EOL;
-        echo '    [--standard=<standard>] [--sniffs=<sniffs>] [--suffix=<suffix>]'.PHP_EOL;
+        echo '    [--standard=<standard>] [--sniffs=<sniffs>] [--exclude=<sniffs>] [--suffix=<suffix>]'.PHP_EOL;
         echo '    [--severity=<severity>] [--error-severity=<severity>] [--warning-severity=<severity>]'.PHP_EOL;
         echo '    [--tab-width=<tabWidth>] [--encoding=<encoding>]'.PHP_EOL;
-        echo '    [--extensions=<extensions>] [--ignore=<patterns>] [--bootstrap=<bootstrap>] <file> ...'.PHP_EOL;
+        echo '    [--extensions=<extensions>] [--ignore=<patterns>] [--bootstrap=<bootstrap>]'.PHP_EOL;
+        echo '    [--file-list=<fileList>] <file> ...'.PHP_EOL;
         echo '        -n            Do not fix warnings (shortcut for --warning-severity=0)'.PHP_EOL;
         echo '        -w            Fix both warnings and errors (on by default)'.PHP_EOL;
         echo '        -l            Local directory only, no recursion'.PHP_EOL;
@@ -1283,6 +1361,7 @@ class PHP_CodeSniffer_CLI
         echo '        --version     Print version information'.PHP_EOL;
         echo '        --no-patch    Do not make use of the "diff" or "patch" programs'.PHP_EOL;
         echo '        <file>        One or more files and/or directories to fix'.PHP_EOL;
+        echo '        <fileList>    A file containing a list of files and/or directories to fix (one per line)'.PHP_EOL;
         echo '        <stdinPath>   If processing STDIN, the file path that STDIN will be processed as '.PHP_EOL;
         echo '        <bootstrap>   A comma separated list of files to run before processing starts'.PHP_EOL;
         echo '        <encoding>    The encoding of the files being fixed (default is iso-8859-1)'.PHP_EOL;
@@ -1291,7 +1370,7 @@ class PHP_CodeSniffer_CLI
         echo '                      The type of the file can be specified using: ext/type'.PHP_EOL;
         echo '                      e.g., module/php,es/js'.PHP_EOL;
         echo '        <patterns>    A comma separated list of patterns to ignore files and directories'.PHP_EOL;
-        echo '        <sniffs>      A comma separated list of sniff codes to limit the fixes to'.PHP_EOL;
+        echo '        <sniffs>      A comma separated list of sniff codes to include or exclude during fixing'.PHP_EOL;
         echo '                      (all sniffs must be part of the specified standard)'.PHP_EOL;
         echo '        <severity>    The minimum severity required to fix an error or warning'.PHP_EOL;
         echo '        <standard>    The name or path of the coding standard to use'.PHP_EOL;
