@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Files_LineEndingsSniff implements PHP_CodeSniffer_Sniff
@@ -129,7 +129,13 @@ class Generic_Sniffs_Files_LineEndingsSniff implements PHP_CodeSniffer_Sniff
                     || $tokens[($i + 1)]['line'] > $tokens[$i]['line']
                 ) {
                     // Token is the last on a line.
-                    $newContent  = rtrim($tokens[$i]['content'], "\r\n");
+                    if (isset($tokens[$i]['orig_content']) === true) {
+                        $tokenContent = $tokens[$i]['orig_content'];
+                    } else {
+                        $tokenContent = $tokens[$i]['content'];
+                    }
+
+                    $newContent  = rtrim($tokenContent, "\r\n");
                     $newContent .= $eolChar;
                     $phpcsFile->fixer->replaceToken($i, $newContent);
                 }
