@@ -26,7 +26,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Files_LineLengthSniff implements PHP_CodeSniffer_Sniff
@@ -127,6 +127,30 @@ class Generic_Sniffs_Files_LineLengthSniff implements PHP_CodeSniffer_Sniff
             $phpcsFile->recordMetric($stackPtr, 'Line length', '151 or more');
         }
 
+        // If this is a long comment, check if it can be broken up onto multiple lines.
+        // Some comments contain unbreakable strings like URLs and so it makes sense
+        // to ignore the line length in these cases if the URL would be longer than the max
+        // line length once you indent it to the correct level.
+        if ($lineLength > $this->lineLimit
+            && ($tokens[$stackPtr]['code'] === T_COMMENT
+            || $tokens[$stackPtr]['code'] === T_DOC_COMMENT_STRING)
+        ) {
+            $oldLength = strlen($tokens[$stackPtr]['content']);
+            $newLength = strlen(ltrim($tokens[$stackPtr]['content'], "/#\t "));
+            $indent    = (($tokens[$stackPtr]['column'] - 1) + ($oldLength - $newLength));
+
+            $nonBreakingLength = $tokens[$stackPtr]['length'];
+
+            $space = strrpos($tokens[$stackPtr]['content'], ' ');
+            if ($space !== false) {
+                $nonBreakingLength -= ($space + 1);
+            }
+
+            if (($nonBreakingLength + $indent) > $this->lineLimit) {
+                return;
+            }
+        }
+
         if ($this->absoluteLineLimit > 0
             && $lineLength > $this->absoluteLineLimit
         ) {
