@@ -25,7 +25,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Functions_OpeningFunctionBraceKernighanRitchieSniff implements PHP_CodeSniffer_Sniff
@@ -111,9 +111,26 @@ class Generic_Sniffs_Functions_OpeningFunctionBraceKernighanRitchieSniff impleme
                 $phpcsFile->fixer->beginChangeset();
                 $phpcsFile->fixer->addContent($prev, ' {');
                 $phpcsFile->fixer->replaceToken($openingBrace, '');
+                if ($tokens[($openingBrace + 1)]['code'] === T_WHITESPACE
+                    && $tokens[($openingBrace + 2)]['line'] > $tokens[$openingBrace]['line']
+                ) {
+                    // Brace is followed by a new line, so remove it to ensure we don't
+                    // leave behind a blank line at the top of the block.
+                    $phpcsFile->fixer->replaceToken(($openingBrace + 1), '');
+
+                    if ($tokens[($openingBrace - 1)]['code'] === T_WHITESPACE
+                        && $tokens[($openingBrace - 1)]['line'] === $tokens[$openingBrace]['line']
+                        && $tokens[($openingBrace - 2)]['line'] < $tokens[$openingBrace]['line']
+                    ) {
+                        // Brace is preceeded by indent, so remove it to ensure we don't
+                        // leave behind more indent than is required for the first line.
+                        $phpcsFile->fixer->replaceToken(($openingBrace - 1), '');
+                    }
+                }
+
                 $phpcsFile->fixer->endChangeset();
-            }
-        }
+            }//end if
+        }//end if
 
         $phpcsFile->recordMetric($stackPtr, 'Function opening brace placement', 'same line');
 
@@ -136,23 +153,23 @@ class Generic_Sniffs_Functions_OpeningFunctionBraceKernighanRitchieSniff impleme
             return;
         }
 
-        if ($tokens[($closeBracket + 1)]['code'] !== T_WHITESPACE) {
+        if ($tokens[($openingBrace - 1)]['code'] !== T_WHITESPACE) {
             $length = 0;
-        } else if ($tokens[($closeBracket + 1)]['content'] === "\t") {
+        } else if ($tokens[($openingBrace - 1)]['content'] === "\t") {
             $length = '\t';
         } else {
-            $length = strlen($tokens[($closeBracket + 1)]['content']);
+            $length = strlen($tokens[($openingBrace - 1)]['content']);
         }
 
         if ($length !== 1) {
-            $error = 'Expected 1 space after closing parenthesis; found %s';
+            $error = 'Expected 1 space before opening brace; found %s';
             $data  = array($length);
-            $fix   = $phpcsFile->addFixableError($error, $closeBracket, 'SpaceAfterBracket', $data);
+            $fix   = $phpcsFile->addFixableError($error, $closeBracket, 'SpaceBeforeBrace', $data);
             if ($fix === true) {
                 if ($length === 0 || $length === '\t') {
-                    $phpcsFile->fixer->addContent($closeBracket, ' ');
+                    $phpcsFile->fixer->addContentBefore($openingBrace, ' ');
                 } else {
-                    $phpcsFile->fixer->replaceToken(($closeBracket + 1), ' ');
+                    $phpcsFile->fixer->replaceToken(($openingBrace - 1), ' ');
                 }
             }
         }
