@@ -24,12 +24,19 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_PHP_SyntaxSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * The path to the PHP version we are checking with.
+     *
+     * @var string
+     */
+    private $_phpPath = null;
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -54,18 +61,20 @@ class Generic_Sniffs_PHP_SyntaxSniff implements PHP_CodeSniffer_Sniff
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
-        $phpPath = PHP_CodeSniffer::getConfigData('php_path');
-        if ($phpPath === null) {
-            // PHP_BINARY is available in PHP 5.4+.
-            if (defined('PHP_BINARY') === true) {
-                $phpPath = PHP_BINARY;
-            } else {
-                return;
+        if ($this->_phpPath === null) {
+            $this->_phpPath = PHP_CodeSniffer::getConfigData('php_path');
+            if ($this->_phpPath === null) {
+                // PHP_BINARY is available in PHP 5.4+.
+                if (defined('PHP_BINARY') === true) {
+                    $this->_phpPath = PHP_BINARY;
+                } else {
+                    return;
+                }
             }
         }
 
         $fileName = $phpcsFile->getFilename();
-        $cmd      = "$phpPath -l \"$fileName\" 2>&1";
+        $cmd      = $this->_phpPath." -l \"$fileName\" 2>&1";
         $output   = shell_exec($cmd);
 
         $matches = array();
