@@ -25,38 +25,63 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_PHP_DisallowShortOpenTagUnitTest extends AbstractSniffUnitTest
 {
 
 
+    /**
+     * Get a list of all test files to check.
+     *
+     * @param string $testFileBase The base path that the unit tests files will have.
+     *
+     * @return string[]
+     */
+    protected function getTestFiles($testFileBase)
+    {
+        $testFiles = array($testFileBase.'1.inc');
+
+        $option = (boolean) ini_get('short_open_tag');
+        if ($option === true || defined('HHVM_VERSION') === true) {
+            $testFiles[] = $testFileBase.'2.inc';
+        }
+
+        return $testFiles;
+
+    }//end getTestFiles()
+
+
     /**
      * Returns the lines where errors should occur.
      *
      * The key of the array should represent the line number and the value
      * should represent the number of errors that should occur on that line.
      *
+     * @param string $testFile The name of the file being tested.
+     *
      * @return array<int, int>
      */
-    public function getErrorList()
+    public function getErrorList($testFile='')
     {
-        $option = (boolean) ini_get('short_open_tag');
-        if ($option === true || defined('HHVM_VERSION') === true) {
+        switch ($testFile) {
+        case 'DisallowShortOpenTagUnitTest.1.inc':
             return array(
-                    4 => 1,
                     5 => 1,
+                    6 => 1,
+                    7 => 1,
+                    10 => 1,
                    );
-        } else if (version_compare(PHP_VERSION, '5.4.0RC1') >= 0) {
-            // Shorthand echo is always available from PHP 5.4.0 but needed the
-            // short_open_tag ini var to be set for versions before this.
+        case 'DisallowShortOpenTagUnitTest.2.inc':
             return array(
+                    2 => 1,
+                    3 => 1,
                     4 => 1,
                    );
-        }
-
-        return array();
+        default:
+            return array();
+        }//end switch
 
     }//end getErrorList()
 
