@@ -22,7 +22,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -172,10 +172,6 @@ class PEAR_Sniffs_Commenting_FileCommentSniff implements PHP_CodeSniffer_Sniff
                    T_ABSTRACT,
                    T_CONST,
                    T_PROPERTY,
-                   T_INCLUDE,
-                   T_INCLUDE_ONCE,
-                   T_REQUIRE,
-                   T_REQUIRE_ONCE,
                   );
 
         if (in_array($tokens[$nextToken]['code'], $ignore) === true) {
