@@ -22,7 +22,7 @@
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_CSS_DuplicateClassDefinitionSniff implements PHP_CodeSniffer_Sniff
@@ -69,8 +69,13 @@ class Squiz_Sniffs_CSS_DuplicateClassDefinitionSniff implements PHP_CodeSniffer_
             return;
         }
 
+        // Save the class names in a "scope",
+        // to prevent false positives with @media blocks.
+        $scope = 'main';
+
         $find = array(
                  T_CLOSE_CURLY_BRACKET,
+                 T_OPEN_CURLY_BRACKET,
                  T_COMMENT,
                  T_OPEN_TAG,
                 );
@@ -78,6 +83,14 @@ class Squiz_Sniffs_CSS_DuplicateClassDefinitionSniff implements PHP_CodeSniffer_
         while ($next !== false) {
             $prev = $phpcsFile->findPrevious($find, ($next - 1));
 
+            // Check if an inner block was closed.
+            $beforePrev = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($prev - 1), null, true);
+            if ($beforePrev !== false
+                && $tokens[$beforePrev]['code'] === T_CLOSE_CURLY_BRACKET
+            ) {
+                $scope = 'main';
+            }
+
             // Create a sorted name for the class so we can compare classes
             // even when the individual names are all over the place.
             $name = '';
@@ -94,13 +107,16 @@ class Squiz_Sniffs_CSS_DuplicateClassDefinitionSniff implements PHP_CodeSniffer_
             sort($names);
             $name = implode(',', $names);
 
-            if (isset($classNames[$name]) === true) {
-                $first = $classNames[$name];
+            if ($name{0} === '@') {
+                // Media block has its own "scope".
+                $scope = $name;
+            } else if (isset($classNames[$scope][$name]) === true) {
+                $first = $classNames[$scope][$name];
                 $error = 'Duplicate class definition found; first defined on line %s';
                 $data  = array($tokens[$first]['line']);
                 $phpcsFile->addError($error, $next, 'Found', $data);
             } else {
-                $classNames[$name] = $next;
+                $classNames[$scope][$name] = $next;
             }
 
             $next = $phpcsFile->findNext(T_OPEN_CURLY_BRACKET, ($next + 1));
