@@ -31,7 +31,7 @@ if (class_exists('PHP_CodeSniffer_Standards_AbstractScopeSniff', true) === false
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Commenting_FunctionCommentThrowTagSniff extends PHP_CodeSniffer_Standards_AbstractScopeSniff
@@ -84,17 +84,16 @@ class Squiz_Sniffs_Commenting_FunctionCommentThrowTagSniff extends PHP_CodeSniff
             return;
         }
 
-        // Find the position where the current function scope ends.
-        $currScopeEnd = 0;
-        if (isset($tokens[$currScope]['scope_closer']) === true) {
-            $currScopeEnd = $tokens[$currScope]['scope_closer'];
-        }
+        $currScopeEnd = $tokens[$currScope]['scope_closer'];
 
         // Find all the exception type token within the current scope.
         $throwTokens = array();
         $currPos     = $stackPtr;
-        if ($currScopeEnd !== 0) {
-            while ($currPos < $currScopeEnd && $currPos !== false) {
+        $foundThrows = false;
+        while ($currPos < $currScopeEnd && $currPos !== false) {
+            if ($phpcsFile->hasCondition($currPos, T_CLOSURE) === false) {
+                $foundThrows = true;
+
                 /*
                     If we can't find a NEW, we are probably throwing
                     a variable, so we ignore it, but they still need to
@@ -136,10 +135,14 @@ class Squiz_Sniffs_Commenting_FunctionCommentThrowTagSniff extends PHP_CodeSniff
                         }
                     }//end if
                 }//end if
+            }//end if
 
-                $currPos = $phpcsFile->findNext(T_THROW, ($currPos + 1), $currScopeEnd);
-            }//end while
-        }//end if
+            $currPos = $phpcsFile->findNext(T_THROW, ($currPos + 1), $currScopeEnd);
+        }//end while
+
+        if ($foundThrows === false) {
+            return;
+        }
 
         // Only need one @throws tag for each type of exception thrown.
         $throwTokens = array_unique($throwTokens);
