@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sniff
@@ -109,6 +109,25 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
             }
         }//end if
 
+        // Tokens that are allowed inside a bracketed operation.
+        $allowed = array(
+                    T_VARIABLE,
+                    T_LNUMBER,
+                    T_DNUMBER,
+                    T_STRING,
+                    T_WHITESPACE,
+                    T_THIS,
+                    T_SELF,
+                    T_OBJECT_OPERATOR,
+                    T_DOUBLE_COLON,
+                    T_OPEN_SQUARE_BRACKET,
+                    T_CLOSE_SQUARE_BRACKET,
+                    T_MODULUS,
+                    T_NONE,
+                   );
+
+        $allowed += PHP_CodeSniffer_Tokens::$operators;
+
         $lastBracket = false;
         if (isset($tokens[$stackPtr]['nested_parenthesis']) === true) {
             $parenthesis = array_reverse($tokens[$stackPtr]['nested_parenthesis'], true);
@@ -123,23 +142,8 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                 }
 
                 if ($prevCode === T_STRING || $prevCode === T_SWITCH) {
-                    // We allow very simple operations to not be bracketed.
+                    // We allow simple operations to not be bracketed.
                     // For example, ceil($one / $two).
-                    $allowed = array(
-                                T_VARIABLE,
-                                T_LNUMBER,
-                                T_DNUMBER,
-                                T_STRING,
-                                T_WHITESPACE,
-                                T_THIS,
-                                T_SELF,
-                                T_OBJECT_OPERATOR,
-                                T_DOUBLE_COLON,
-                                T_OPEN_SQUARE_BRACKET,
-                                T_CLOSE_SQUARE_BRACKET,
-                                T_MODULUS,
-                               );
-
                     for ($prev = ($stackPtr - 1); $prev > $bracket; $prev--) {
                         if (in_array($tokens[$prev]['code'], $allowed) === true) {
                             continue;
@@ -281,6 +285,7 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                     T_MODULUS         => true,
                     T_ISSET           => true,
                     T_ARRAY           => true,
+                    T_NONE            => true,
                    );
 
         // Find the first token in the expression.
