@@ -24,7 +24,7 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements PHP_CodeSniffer_Sniff
@@ -198,13 +198,14 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
                 }
             }
 
-            // Take references into account when expecting the
-            // location of whitespace.
             $checkToken = ($nextParam - 1);
-            if ($tokens[$checkToken]['code'] === T_ELLIPSIS) {
-                $checkToken--;
+            $prev       = $phpcsFile->findPrevious(T_WHITESPACE, $checkToken, null, true);
+            if ($tokens[$prev]['code'] === T_ELLIPSIS) {
+                $checkToken = ($prev - 1);
             }
 
+            // Take references into account when expecting the
+            // location of whitespace.
             if ($phpcsFile->isReference($checkToken) === true) {
                 $whitespace = ($checkToken - 1);
             } else {
@@ -311,7 +312,7 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
                     $nextToken++;
                 }
 
-                if ($nextToken !== $nextParam) {
+                if ($tokens[$nextToken]['code'] !== T_ELLIPSIS && $nextToken !== $nextParam) {
                     // There was a type hint, so check the spacing between
                     // the hint and the variable as well.
                     $hint = $tokens[$nextToken]['content'];
