@@ -24,12 +24,31 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_PHP_LowercasePHPFunctionsSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * String -> int hash map of all php built in function names
+     *
+     * @var array
+     */
+    private $_builtInFunctions;
+
+
+    /**
+     * Construct the LowercasePHPFunctionSniff
+     */
+    public function __construct()
+    {
+
+        $allFunctions            = get_defined_functions();
+        $this->_builtInFunctions = array_flip($allFunctions['internal']);
+
+    }//end __construct()
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -95,11 +114,10 @@ class Squiz_Sniffs_PHP_LowercasePHPFunctionsSniff implements PHP_CodeSniffer_Sni
         }
 
         // Make sure it is an inbuilt PHP function.
-        // PHP_CodeSniffer doesn't include/require any files, so no
-        // user defined global functions can exist, except for
-        // PHP_CodeSniffer ones.
+        // PHP_CodeSniffer can possibly include user defined functions
+        // through the use of vendor/autoload.php.
         $content = $tokens[$stackPtr]['content'];
-        if (function_exists($content) === false) {
+        if (isset($this->_builtInFunctions[strtolower($content)]) === false) {
             return;
         }
 
