@@ -25,13 +25,27 @@
  * @author    Marc McIntyre <mmcintyre@squiz.net>
  * @copyright 2006-2014 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   https://github.com/squizlabs/PHP_CodeSniffer/blob/master/licence.txt BSD Licence
- * @version   Release: 2.6.1
+ * @version   Release: 2.7.0
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_Commenting_BlockCommentUnitTest extends AbstractSniffUnitTest
 {
 
 
+    /**
+     * Get a list of CLI values to set befor the file is tested.
+     *
+     * @param string $testFile The name of the file being tested.
+     *
+     * @return array
+     */
+    public function getCliValues($testFile)
+    {
+        return array('--tab-width=4');
+
+    }//end getCliValues()
+
+
     /**
      * Returns the lines where errors should occur.
      *
@@ -71,6 +85,9 @@ class Squiz_Tests_Commenting_BlockCommentUnitTest extends AbstractSniffUnitTest
                    159 => 1,
                    181 => 1,
                    188 => 1,
+                   206 => 1,
+                   207 => 1,
+                   214 => 1,
                   );
 
         return $errors;
